"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Directive = void 0;
const graphql_1 = require("graphql");
const GQLElement_1 = require("../../classes/GQLElement");
class Directive extends GQLElement_1.GQLElement {
    constructor(name) {
        super(name);
        this._args = [];
    }
    get args() {
        return this._args;
    }
    get definitionNode() {
        return {
            kind: "Directive",
            name: {
                kind: "Name",
                value: this.name,
            },
            arguments: this._args.map((a) => {
                let value = a[1];
                if (typeof value === "object") {
                    value = JSON.stringify(value);
                }
                else {
                    value = value.toString();
                }
                return {
                    kind: "Argument",
                    name: {
                        kind: "Name",
                        value: a[0],
                    },
                    value: graphql_1.parseValue(value),
                };
            }),
        };
    }
    static create(name) {
        return new Directive(name);
    }
    addArg(name, value) {
        this._args = [...this._args, [name, value]];
        return this;
    }
}
exports.Directive = Directive;
//# sourceMappingURL=Directive.js.map